# Consumption

> see https://aka.ms/autorest

This is the AutoRest configuration file for Consumption.



---
## Getting Started
To build the SDK for Consumption, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration



### Basic Information
These are the global settings for the Consumption API.

``` yaml
openapi-type: arm
tag: package-2018-06
```

### Tag: package-2017-11

These settings apply only when `--tag=package-2017-11` is specified on the command line.

``` yaml $(tag) == 'package-2017-11'
input-file:
- Microsoft.Consumption/stable/2017-11-30/consumption.json
```

---
### Tag: package-2018-01

These settings apply only when `--tag=package-2018-01` is specified on the command line.

``` yaml $(tag) == 'package-2018-01'
input-file:
- Microsoft.Consumption/stable/2018-01-31/consumption.json
```

---
### Tag: package-2018-03

These settings apply only when `--tag=package-2018-03` is specified on the command line.

``` yaml $(tag) == 'package-2018-03'
input-file:
- Microsoft.Consumption/stable/2018-03-31/consumption.json
```

---
### Tag: package-2018-05

These settings apply only when `--tag=package-2018-05` is specified on the command line.

``` yaml $(tag) == 'package-2018-05'
input-file:
- Microsoft.Consumption/stable/2018-05-31/consumption.json
```

---
### Tag: package-2018-06

These settings apply only when `--tag=package-2018-06` is specified on the command line.

``` yaml $(tag) == 'package-2018-06'
input-file:
- Microsoft.Consumption/stable/2018-06-30/consumption.json
```

## Suppression
``` yaml
directive:
  - suppress: R2059
    from: consumption.json
    reason: it's not actually a resource path; the validator is confused because the Billing namespace is in the URI path.
    approved-by: "@fearthecowboy"
```

---
### Tag: package-2017-04-preview

These settings apply only when `--tag=package-2017-04-preview` is specified on the command line.

``` yaml $(tag) == 'package-2017-04-preview'
input-file:
- Microsoft.Consumption/preview/2017-04-24-preview/consumption.json
```

---
### Tag: package-2017-12-preview

These settings apply only when `--tag=package-2017-12-preview` is specified on the command line.

``` yaml $(tag) == 'package-2017-12-preview'
input-file:
- Microsoft.Consumption/preview/2017-12-30-preview/consumption.json
```

---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_consumption']
```


## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.Consumption
  output-folder: $(csharp-sdks-folder)/Consumption/Management.Consumption/Generated
  clear-output-folder: true
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python)
python-mode: create
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.mgmt.consumption
  package-name: azure-mgmt-consumption
  package-version: 1.2.0
  clear-output-folder: true
```
``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-mgmt-consumption/azure/mgmt/consumption
```
``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/azure-mgmt-consumption
```


## Go

These settings apply only when `--go` is specified on the command line.

``` yaml $(go)
go:
  license-header: MICROSOFT_APACHE_NO_VERSION
  namespace: consumption
  clear-output-folder: true
```

### Go multi-api
``` yaml $(go) && $(multiapi)
batch:
   - tag: package-2017-04-preview
   - tag: package-2017-11
   - tag: package-2017-12-preview
   - tag: package-2018-01
   - tag: package-2018-03
   - tag: package-2018-05
   - tag: package-2018-06
```


### Tag: package-2017-04-preview and go

These settings apply only when `--tag=package-2017-04-preview --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-2017-04-preview' && $(go)
output-folder: $(go-sdk-folder)/services/preview/consumption/mgmt/2017-04-24-preview/consumption
```

### Tag: package-2017-11 and go
These settings apply only when `--tag=package-2017-11 --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-2017-11' && $(go)
output-folder: $(go-sdk-folder)/services/consumption/mgmt/2017-11-30/consumption
```

### Tag: package-2017-12-preview and go
These settings apply only when `--tag=package-2017-12-preview --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-2017-12-preview' && $(go)
output-folder: $(go-sdk-folder)/services/preview/consumption/mgmt/2017-12-30-preview/consumption
```

### Tag: package-2018-01 and go
These settings apply only when `--tag=package-2018-01 --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-2018-01' && $(go)
output-folder: $(go-sdk-folder)/services/consumption/mgmt/2018-01-31/consumption
```

### Tag: package-2018-03 and go
These settings apply only when `--tag=package-2018-03 --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-2018-03' && $(go)
output-folder: $(go-sdk-folder)/services/consumption/mgmt/2018-03-31/consumption
```

### Tag: package-2018-05 and go
These settings apply only when `--tag=package-2018-05 --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-2018-05' && $(go)
output-folder: $(go-sdk-folder)/services/consumption/mgmt/2018-05-31/consumption
```

### Tag: package-2018-06 and go
These settings apply only when `--tag=package-2018-06 --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-2018-06' && $(go)
output-folder: $(go-sdk-folder)/services/consumption/mgmt/2018-06-30/consumption
```

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.consumption
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-consumption
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2017-04-preview
  - tag: package-2017-11
  - tag: package-2018-01
  - tag: package-2018-03
  - tag: package-2017-12-preview
  - tag: package-2018-05
  - tag: package-2018-06
```

### Tag: package-2017-04-preview and java

These settings apply only when `--tag=package-2017-04-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2017-04-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.consumption.v2017_04_24_preview
  output-folder: $(azure-libraries-for-java-folder)/consumption/resource-manager/v2017_04_24_preview
regenerate-manager: true
generate-interface: true
```

### Tag: package-2017-11 and java

These settings apply only when `--tag=package-2017-11 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2017-11' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.consumption.v2017_11_30
  output-folder: $(azure-libraries-for-java-folder)/consumption/resource-manager/v2017_11_30
regenerate-manager: true
generate-interface: true
```

### Tag: package-2018-01 and java

These settings apply only when `--tag=package-2018-01 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2018-01' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.consumption.v2018_01_31
  output-folder: $(azure-libraries-for-java-folder)/consumption/resource-manager/v2018_01_31
regenerate-manager: true
generate-interface: true
```

### Tag: package-2018-03 and java

These settings apply only when `--tag=package-2018-03 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2018-03' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.consumption.v2018_03_31
  output-folder: $(azure-libraries-for-java-folder)/consumption/resource-manager/v2018_03_31
regenerate-manager: true
generate-interface: true
```

### Tag: package-2017-12-preview and java

These settings apply only when `--tag=package-2017-12-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2017-12-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.consumption.v2017_12_30_preview
  output-folder: $(azure-libraries-for-java-folder)/consumption/resource-manager/v2017_12_30_preview
regenerate-manager: true
generate-interface: true
```

### Tag: package-2018-05 and java

These settings apply only when `--tag=package-2018-05 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2018-05' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.consumption.v2018_05_31
  output-folder: $(azure-libraries-for-java-folder)/consumption/resource-manager/v2018_05_31
regenerate-manager: true
generate-interface: true
```

### Tag: package-2018-06 and java

These settings apply only when `--tag=package-2018-06 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2018-06' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.consumption.v2018_06_30
  output-folder: $(azure-libraries-for-java-folder)/consumption/resource-manager/v2018_06_30
regenerate-manager: true
generate-interface: true
```


